@@ -95,10 +95,7 @@ def write_material_config(material, dir_path, volume_element=None, part_paths=No
             grain_idx : nested list or ndarray of dimension three
                 A mapping that determines the grain index for each voxel.
             size : list of length three, optional
-                Volume element size. By default, set to unit size: `[1, 1, 1]`.
-            orientations : ndarray of shape (N, 3)
-            sample_coordinate_system : dict
-            model_coordinate_system : dict
+                Volume element size. By default set, to unit size: `[1, 1, 1]`.
     part_paths : dict of (str : str)
         Keys are parts and values are paths to files containing the configuration for that
         part. If `volume_element` is not specified, `part_paths` must contain at least the
@@ -111,17 +108,6 @@ def write_material_config(material, dir_path, volume_element=None, part_paths=No
 
     """
 
-    print(f'write_material_config: volume_element.keys(): {volume_element.keys()}')
-
-    axes = ['x', 'y', 'z']
-    if (volume_element.get('sample_coordinate_system') and
-            volume_element.get('model_coordinate_system')):
-        SCS_inv = {v: k for k, v in volume_element['sample_coordinate_system'].items()}
-        axes = [('+' if not SCS_inv[v].startswith('-') else '') + f'{SCS_inv[v]}'
-                for v in volume_element['model_coordinate_system'].values()]
-
-    print('axes: {}'.format(axes))
-
     def format_part_name(name):
         part_delim = '#-------------------#'
         return f'{part_delim}\n<{name}>\n{part_delim}\n'
@@ -212,7 +198,6 @@ def write_material_config(material, dir_path, volume_element=None, part_paths=No
                 grain_idx = zeropad(i + 1, num_grains)
                 tex_spec = (
                     f'[Grain{grain_idx}]\n'
-                    f'axes {axes[0]} {axes[1]} {axes[2]}\n'
                     f'(gauss) phi1 {ori[i][0]:8.4f} Phi {ori[i][1]:8.4f} '
                     f'phi2 {ori[i][2]:8.4f} scatter 0.0 fraction 1.0\n'
                 )
